@@ -114,6 +114,7 @@ lookup_extension (p11_builder *builder,
 	CK_OBJECT_CLASS klass = CKO_X_CERTIFICATE_EXTENSION;
 	CK_OBJECT_HANDLE obj;
 	CK_ATTRIBUTE *attrs;
+	CK_ATTRIBUTE *label;
 	void *value;
 	size_t length;
 	node_asn *node;
@@ -125,7 +126,7 @@ lookup_extension (p11_builder *builder,
 		{ CKA_INVALID },
 	};
 
-	if (public_key == NULL)
+	if (public_key == NULL || public_key->type == CKA_INVALID)
 		public_key = p11_attrs_find_valid (cert, CKA_X_PUBLIC_KEY_INFO);
 
 	/* Look for a stapled certificate extension */
@@ -137,7 +138,15 @@ lookup_extension (p11_builder *builder,
 			value = p11_attrs_find_value (attrs, CKA_VALUE, &length);
 			if (value != NULL) {
 				node = decode_or_get_asn1 (builder, "PKIX1.Extension", value, length);
-				return_val_if_fail (node != NULL, NULL);
+				if (node == NULL) {
+					label = p11_attrs_find_valid (attrs, CKA_LABEL);
+					if (label == NULL)
+						label = p11_attrs_find_valid (cert, CKA_LABEL);
+					p11_message ("%.*s: invalid certificate extension",
+							label ? (int)label->ulValueLen : 7,
+							label ? (char *)label->pValue : "unknown");
+					return NULL;
+				}
 				return p11_asn1_read (node, "extnValue", ext_len);
 			}
 		}
@@ -551,6 +560,7 @@ calc_certificate_category (p11_builder *builder,
                            CK_ATTRIBUTE *public_key,
                            CK_ULONG *category)
 {
+	CK_ATTRIBUTE *label;
 	unsigned char *ext;
 	size_t ext_len;
 	bool is_ca = 0;
@@ -570,7 +580,10 @@ calc_certificate_category (p11_builder *builder,
 		ret = p11_x509_parse_basic_constraints (builder->asn1_defs, ext, ext_len, &is_ca);
 		free (ext);
 		if (!ret) {
-			p11_message ("invalid basic constraints certificate extension");
+			label = p11_attrs_find_valid (cert, CKA_LABEL);
+			p11_message ("%.*s: invalid basic constraints certificate extension",
+				     label ? (int)label->ulValueLen : 7,
+				     label ? (char *)label->pValue : "unknown");
 			return false;
 		}
 
